from sports.nba.nba_team import NBA_Team


class BostonCeltics(NBA_Team):
    """
    NBA Golden State Warriors Static Information

    """

    full_name = "Boston Celtics"
    name = "Celtics"
    team_id = 1610612738

    def __init__(self):
        """
        """
        super().__init__()
